@@ -84,7 +84,7 @@ int
 _gnutls_x509_crt_cpy (gnutls_x509_crt_t dest, gnutls_x509_crt_t src)
 {
   int ret;
-  size_t der_size;
+  size_t der_size = 0;
   opaque *der;
   gnutls_datum_t tmp;
 
@@ -123,7 +123,6 @@ _gnutls_x509_crt_cpy (gnutls_x509_crt_t dest, gnutls_x509_crt_t src)
     }
 
   return 0;
-
 }
 
 /**
@@ -1049,7 +1048,7 @@ _gnutls_parse_general_name (ASN1_TYPE src, const char *src_name,
               size_t orig_name_size = *name_size;
 
               result = asn1_create_element
-                (_gnutls_get_pkix (), "PKIX1.XmppAddr", &c2);
+                (_gnutls_get_pkix (), "PKIX1.UTF8String", &c2);
               if (result != ASN1_SUCCESS)
                 {
                   gnutls_assert ();
